==> hadoop-3.2.4-src.tar.gz: hadoop-3.2.4-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-applications/hadoop-yarn-services/hadoop-yarn-services-core/src/main/java/org/apache/hadoop/yarn/service/component/instance/ComponentInstanceEvent.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.yarn.service.component.instance;

import com.google.common.base.Preconditions;
import org.apache.hadoop.yarn.api.records.ContainerId;
import org.apache.hadoop.yarn.api.records.ContainerStatus;
import org.apache.hadoop.yarn.event.AbstractEvent;

public class ComponentInstanceEvent
    extends AbstractEvent<ComponentInstanceEventType> {

  private ContainerId id;
  private ContainerStatus status;
  private boolean shouldDestroy = false;

  public ComponentInstanceEvent(ContainerId containerId,
      ComponentInstanceEventType componentInstanceEventType) {
    super(componentInstanceEventType);
    Preconditions.checkNotNull(containerId);
    this.id = containerId;
  }

  public ContainerId getContainerId() {
    return id;
  }

  public ContainerStatus getStatus() {
    return this.status;
  }

  public ComponentInstanceEvent setStatus(ContainerStatus status) {
    this.status = status;
    return this;
  }

  public void setShouldDestroy() {
    shouldDestroy = true;
  }

  public boolean shouldDestroy() {
    return shouldDestroy;
  }
}

==> hadoop-3.3.5-src.tar.gz: hadoop-3.3.5-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-applications/hadoop-yarn-services/hadoop-yarn-services-core/src/main/java/org/apache/hadoop/yarn/service/component/instance/ComponentInstanceEvent.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.yarn.service.component.instance;

import org.apache.hadoop.thirdparty.com.google.common.base.Preconditions;
import org.apache.hadoop.yarn.api.records.ContainerId;
import org.apache.hadoop.yarn.api.records.ContainerStatus;
import org.apache.hadoop.yarn.event.AbstractEvent;

public class ComponentInstanceEvent
    extends AbstractEvent<ComponentInstanceEventType> {

  private ContainerId id;
  private ContainerStatus status;
  private boolean shouldDestroy = false;

  public ComponentInstanceEvent(ContainerId containerId,
      ComponentInstanceEventType componentInstanceEventType) {
    super(componentInstanceEventType);
    Preconditions.checkNotNull(containerId);
    this.id = containerId;
  }

  public ContainerId getContainerId() {
    return id;
  }

  public ContainerStatus getStatus() {
    return this.status;
  }

  public ComponentInstanceEvent setStatus(ContainerStatus status) {
    this.status = status;
    return this;
  }

  public void setShouldDestroy() {
    shouldDestroy = true;
  }

  public boolean shouldDestroy() {
    return shouldDestroy;
  }
}
